/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayForm, {ClaySelect} from '@clayui/form';
import ClayTable from '@clayui/table';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';

const ImportMappingItem = ({
	dbField,
	fileFields,
	formEvaluated,
	portletNamespace,
	previewValue,
	required,
	selectedFileField,
	updateFieldMapping,
}) => {
	const inputId = `input-field-${dbField.name}`;
	const hasError = formEvaluated && required && !selectedFileField;

	const hasSuccess = formEvaluated && !hasError;

	return (
		<ClayTable.Row>
			<ClayTable.Cell>
				<label htmlFor={inputId}>{dbField.name}</label>

				{dbField.description && (
					<p className="mb-0">{dbField.description}</p>
				)}
			</ClayTable.Cell>

			<ClayTable.Cell>
				<ClayForm.Group
					className={classNames({
						'has-error': hasError,
						'has-success': hasSuccess,
						'mb-0': true,
					})}
				>
					{selectedFileField && (
						<input
							hidden
							name={`${portletNamespace}internalFieldName_${dbField.name}`}
							readOnly
							value={dbField.name}
						/>
					)}

					<ClaySelect
						aria-required={required}
						disabled={!fileFields}
						id={inputId}
						name={
							selectedFileField &&
							`${portletNamespace}externalFieldName_${dbField.name}`
						}
						onChange={(event) =>
							updateFieldMapping(event.target.value)
						}
						value={selectedFileField}
					>
						<ClaySelect.Option label="" value="" />

						{fileFields &&
							fileFields.map((fileField) => {
								const columnHasNoName =
									typeof fileField === 'number';

								const label = columnHasNoName
									? `${Liferay.Language.get('column')} ${
											fileField + 1
									  }`
									: fileField;

								return (
									<ClaySelect.Option
										key={fileField}
										label={label}
										value={String(fileField)}
									/>
								);
							})}
					</ClaySelect>
				</ClayForm.Group>
			</ClayTable.Cell>

			<ClayTable.Cell>{previewValue}</ClayTable.Cell>
		</ClayTable.Row>
	);
};

ImportMappingItem.propTypes = {
	dbField: PropTypes.shape({
		description: PropTypes.string,
		name: PropTypes.string.isRequired,
	}),
	fileFields: PropTypes.arrayOf(
		PropTypes.oneOfType([PropTypes.string, PropTypes.number])
	),
	formEvaluated: PropTypes.bool.isRequired,
	portletNamespace: PropTypes.string.isRequired,
	previewValue: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
	required: PropTypes.bool.isRequired,
	selectedFileField: PropTypes.string.isRequired,
	updateFieldMapping: PropTypes.func.isRequired,
};

export default ImportMappingItem;
