/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import ClayModal, {useModal} from '@clayui/modal';
import PropTypes from 'prop-types';
import React, {useCallback, useState} from 'react';

import ImportPreviewModalBody from './ImportPreviewModalBody';
import ImportProcessModalBody from './ImportProcessModalBody';

function ImportSubmit({
	evaluateForm,
	fieldsSelections,
	fileContent,
	formDataQuerySelector,
	formImportURL,
	formIsValid,
}) {
	const [modalVisibile, setModalVisibile] = useState(false);
	const [stage, setStage] = useState('preview');

	const {observer, onClose} = useModal({
		onClose: () => {
			setStage('preview');

			setModalVisibile(false);
		},
	});

	const showPreviewModal = useCallback(() => {
		evaluateForm();

		if (formIsValid) {
			setModalVisibile(true);
		}
	}, [evaluateForm, formIsValid]);

	return (
		<span className="mr-3">
			<ClayButton
				displayType="primary"
				onClick={showPreviewModal}
				type="button"
			>
				{Liferay.Language.get('next')}
			</ClayButton>

			{modalVisibile && (
				<ClayModal
					observer={observer}
					size={stage === 'import' ? 'md' : 'lg'}
				>
					{stage === 'preview' && (
						<ImportPreviewModalBody
							closeModal={onClose}
							fieldsSelections={fieldsSelections}
							fileContent={fileContent}
							startImport={() => setStage('import')}
						/>
					)}

					{stage === 'import' && (
						<ImportProcessModalBody
							closeModal={onClose}
							formDataQuerySelector={formDataQuerySelector}
							formImportURL={formImportURL}
						/>
					)}
				</ClayModal>
			)}
		</span>
	);
}

ImportSubmit.propTypes = {
	formDataQuerySelector: PropTypes.string.isRequired,
	formImportURL: PropTypes.string.isRequired,
};

export default ImportSubmit;
